@@ -19,19 +19,21 @@ defined('M3_SYSTEM') or die('Access error: Direct access denied.');
 
 global $HELP;
 
-// ########## メインメニュー項目一覧 ##########
-$HELP['menu_list']['title'] = 'メニュー設定一覧';
-$HELP['menu_list']['body'] = '登録されているメニュー設定の一覧です。';
-$HELP['menu_detail']['title'] = 'メニュー設定';
+// ########## メニュー項目一覧 ##########
+$HELP['menu_list']['title'] = '設定一覧';
+$HELP['menu_list']['body'] = '登録されている設定の一覧です。';
+$HELP['menu_detail']['title'] = '基本設定';
 $HELP['menu_detail']['body'] = 'メニューについての設定を行います。';
 $HELP['menu_check']['title'] = '選択用チェックボックス';
 $HELP['menu_check']['body'] = '削除を行う項目を選択します。';
 $HELP['menu_name']['title'] = '名前';
-$HELP['menu_name']['body'] = 'メニュー設定名です。メニューのタイトルにも使用されます。';
+$HELP['menu_name']['body'] = '設定名です。メニューのタイトルにも使用されます。';
 $HELP['menu_name_input']['title'] = '名前';
-$HELP['menu_name_input']['body'] = 'メニュー設定名です。新規に登録するか、登録済みの設定を選択します。';
-$HELP['menu_id']['title'] = 'メニュー設定ID';
-$HELP['menu_id']['body'] = '自動的に振られるメニュー設定IDです。';
+$HELP['menu_name_input']['body'] = '設定名です。新規に登録するか、登録済みの設定を選択します。';
+$HELP['menu_id']['title'] = '設定ID';
+$HELP['menu_id']['body'] = '自動的に振られる設定IDです。';
+$HELP['menu_access_control']['title'] = 'アクセス制御';
+$HELP['menu_access_control']['body'] = 'メニューの表示制御を行います。';
 $HELP['menu_limit_user']['title'] = 'ユーザ制限';
 $HELP['menu_limit_user']['body'] = 'メニューの表示をログインしたユーザに限定するかどうかを設定します。';
 $HELP['menu_design']['title'] = 'デザイン';
@@ -39,13 +41,11 @@ $HELP['menu_design']['body'] = '●階層化あり<br />メニュー定義を単
 $HELP['menu_def']['title'] = 'メニュー定義';
 $HELP['menu_def']['body'] = 'メニュー項目で使用するメニュー定義を選択します。定義データはシステムで共通です。<br />単階層でメニューを定義するか、多階層でメニューを定義するかを選択します。<br />メニューIDは管理機能の「システムマスター管理/メンテナンス/マスター管理/メニューID」で管理します。';
 $HELP['menu_ref']['title'] = '使用';
-$HELP['menu_ref']['body'] = 'メニュー設定を使用しているウィジェット数を示します。使用が0のメニュー設定のみ削除可能です。';
+$HELP['menu_ref']['body'] = '設定を使用しているウィジェット数を示します。使用が0の設定のみ削除可能です。';
 $HELP['menu_list_btn']['title'] = '一覧ボタン';
-$HELP['menu_list_btn']['body'] = 'メニュー設定一覧を表示します。';
+$HELP['menu_list_btn']['body'] = '設定一覧を表示します。';
 $HELP['menu_del_btn']['title'] = '削除ボタン';
-$HELP['menu_del_btn']['body'] = '選択されているメニュー設定を削除します。<br />項目を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['menu_del_btn']['body'] = '選択されている設定を削除します。<br />項目を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['menu_ret_btn']['title'] = '戻るボタン';
-$HELP['menu_ret_btn']['body'] = 'メニュー設定へ戻ります。';
-$HELP['menu_edit_def_btn']['title'] = 'メニュー定義を編集ボタン';
-$HELP['menu_edit_def_btn']['body'] = '選択されているメニュー定義を編集します。';
+$HELP['menu_ret_btn']['body'] = '基本設定へ戻ります。';
 ?>
